@@ -8,7 +8,7 @@ use Data::Dumper;
 our $DEBUG = 0;
 
 sub create {
-    my ($self, $proto) = @_;
+    my ($self, $proto, $param) = @_;
 }
 
 sub retrieve {
@@ -116,3 +116,32 @@ sub store {
 }
 
 1;
+__END__
+
+=head1 NAME
+
+Oryx::DBM::Association::Hash - DBM implementation of hash associations
+
+=head1 SYNOPSIS
+
+See L<Oryx::Association::Hash>.
+
+=head1 DESCRIPTION
+
+This class contains the implementation of hash associations for classes stored via an L<Oryx::DBM> connection.
+
+=head1 SEE ALSO
+
+L<Oryx>, L<Oryx::DBM>, L<Oryx::Association::Hash>
+
+=head1 AUTHOR
+
+Richard Hundt E<lt>richard NO SPAM AT protea-systems.comE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (c) 2005 Richard Hundt.
+
+This library is free software and may be used under the same terms as Perl itself.
+
+=cut
